"""Convert from Arcview ASCII DEMs via native netcdf dem format
to native pts netcdf format for use with least_squares fits
"""

import os
import time


from pyvolution.shallow_water import Domain, Reflective_boundary
from pyvolution.data_manager import convert_dem_from_ascii2netcdf,\
     dem2pts, ferret2sww
from pyvolution.pmesh2domain import pmesh_to_domain_instance 
from caching import cache
import project

#Data preparation
#Convert ASC 2 DEM 2 PTS using source data and store result in source data
demname = project.demname

cache(convert_dem_from_ascii2netcdf, demname, {'verbose': True},
      dependencies = [demname + '.asc'],
      verbose = True)
      #evaluate = True)

cache(dem2pts, demname, {'verbose': True},
      dependencies = [demname + '.dem'],      
      verbose = True)

#Convert MOST boundary

ferret2sww('test', verbose=False,
           origin = (56, 0, 0))


#Read mesh
mesh = project.meshname + '.msh'
domain = cache(pmesh_to_domain_instance, (mesh, Domain),
               dependencies = [mesh],                     
               verbose = True)               


domain.set_name(project.basename)
domain.set_datadir(project.outputdir)
domain.store = True

print "Number of triangles = ", len(domain)
print 'The extent is ', domain.get_extent()


#IC
domain.set_quantity('stage', 0)
domain.set_quantity('elevation',
                    filename = demname + '.pts',
                    use_cache = True,
                    verbose = True)

#BC
Br = Reflective_boundary(domain)
domain.set_boundary( {'wall': Br} )


#Run
for t in domain.evolve(yieldstep = 1, finaltime = 1):
    domain.write_time()
